#!/bin/sh
usage () {
    for x in x; do
        echo 'usage:'
        echo '    ipv4-config.sh static ipv4-address netmask [ gateway ]'
        echo '    ipv4-config.sh dynamic'
        echo '    ipv4-config.sh disabled'
        echo '    ipv4-config.sh defaults'
    done >&2
    exit 1
}

ROOT=/mnt/root
NETWORK_INTERFACES=$ROOT/etc/network/interfaces
DEFAULT_INTERFACES=$ROOT/webgui/defaults/default.interfaces

case "$1" in
    static) ;;
    dynamic) ;;
    disabled) ;;
    defaults) ;;
    *) usage ;;
esac

# if /mnt/root is mounted readonly, remount it
if cp /dev/null /mnt/root/etc/network/interfaces.foo 2>/dev/null ; then
    rm /mnt/root/etc/network/interfaces.foo
else
    FILESYSTEM=`df | awk '$6 == "/mnt/root" { print $1 }`
    case "$FILESYSTEM" in
	"") echo 'cannot find root file system in mount table' >&2 ; exit 1;;
    esac
    echo remounting $FILESYSTEM read-write
    mount -o remount $FILESYSTEM /mnt/root
fi

case "$1" in
    defaults)
	cp $DEFAULT_INTERFACES $NETWORK_INTERFACES
	exit
	;;
esac

for x in x; do
    echo '# DO NOT MODIFY THIS FILE'
    echo '# This file is automatically generated by ipv4-config.sh'
    echo '# '
    echo '# The following settings are for easy parsing'
    echo '#'
    echo '#BEGIN_SAVED_SETTINGS'
    echo '#ConfigVersion=1'
    case "$1" in
        static)
    	echo '#IPv4Address='"$2"
    	echo '#IPv4Netmask='"$3"
    	echo '#IPv4Gateway='"$4"
    	echo '#IPv4UseDHCP=0'
    	;;
        dynamic)
    	echo '#IPv4Address=192.168.0.2'
    	echo '#IPv4Netmask=255.255.255.0'
    	echo '#IPv4Gateway=192.168.0.254'
    	echo '#IPv4UseDHCP=1'
    	;;
        disabled)
    	echo '#IPv4Address=192.168.0.2'
    	echo '#IPv4Netmask=255.255.255.0'
    	echo '#IPv4Gateway=192.168.0.254'
    	echo '#IPv4UseDHCP=2'
    	;;
    esac
    echo '#END_SAVED_SETTINGS'
    echo '#'
    echo '# The loopback network interface'
    echo 'auto lo'
    echo 'iface lo inet loopback'
    echo ''
    case "$1" in
        static)
	    echo 'auto eth0'
	    echo 'iface eth0 inet static'
	    echo '	address '"$2"
	    echo '	netmask '"$3"
	    case "$4" in
		'') ;;
		*) echo '	gateway '"$4" ;;
	    esac
    	    ;;
        dynamic)
	    echo 'allow-hotplug eth0'
	    echo 'iface eth0 inet dhcp'
    	    ;;
        disabled)
    	    ;;
    esac
done > $NETWORK_INTERFACES
